@@ -38,14 +38,14 @@ Notification::Notification(QObject *parent) :
     QObject(parent)
 {
     // devices
-    Q_FOREACH(const NetworkManager::Device::Ptr &device, NetworkManager::networkInterfaces()) {
+    Q_FOREACH (const NetworkManager::Device::Ptr &device, NetworkManager::networkInterfaces()) {
         addDevice(device);
     }
 
     connect(NetworkManager::notifier(), SIGNAL(deviceAdded(QString)), this, SLOT(deviceAdded(QString)));
 
     // connections
-    Q_FOREACH(const NetworkManager::ActiveConnection::Ptr &ac, NetworkManager::activeConnections()) {
+    Q_FOREACH (const NetworkManager::ActiveConnection::Ptr &ac, NetworkManager::activeConnections()) {
         addActiveConnection(ac);
     }
 
@@ -283,6 +283,28 @@ void Notification::stateChanged(NetworkManager::Device::State newstate, NetworkM
         text = i18nc("@info:status Notification when the device failed due to SecondaryConnectionFailed",
                      "A secondary connection of the base connection failed");
         break;
+#if NM_CHECK_VERSION(0, 9, 10)
+    case NetworkManager::Device::DcbFcoeFailed:
+        text = i18nc("@info:status Notification when the device failed due to DcbFcoeFailed",
+                     "DCB or FCoE setup failed");
+        break;
+    case NetworkManager::Device::TeamdControlFailed:
+        text = i18nc("@info:status Notification when the device failed due to TeamdControlFailed",
+                     "teamd control failed");
+        break;
+    case NetworkManager::Device::ModemFailed:
+        text = i18nc("@info:status Notification when the device failed due to ModemFailed",
+                     "Modem failed or no longer available");
+        break;
+    case NetworkManager::Device::ModemAvailable:
+        text = i18nc("@info:status Notification when the device failed due to ModemAvailable",
+                     "Modem now ready and available");
+        break;
+    case NetworkManager::Device::SimPinIncorrect:
+        text = i18nc("@info:status Notification when the device failed due to SimPinIncorrect",
+                     "The SIM PIN was incorrect");
+        break;
+#endif
     case NetworkManager::Device::Reserved:
         return;
     }
@@ -319,7 +341,7 @@ void Notification::addActiveConnection(const NetworkManager::ActiveConnection::P
         connect(vpnConnection.data(), SIGNAL(stateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)),
                 this, SLOT(onVpnConnectionStateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)));
 #if NM_CHECK_VERSION(0, 9, 10)
-    } else if (ac->type() >= NetworkManager::ConnectionSettings::Adsl && ac->type() <= NetworkManager::ConnectionSettings::Team) {
+    } else if (ac->type() != NetworkManager::ConnectionSettings::Generic) {
 #else
     } else {
 #endif
